include <../libs/rounded_shapes.scad>

// For Schrack relays
relay_width = 31/64.0 * 25.4; // Measured at the top of the relay
relay_depth = 72/64.0 * 25.4; // Measured at the top of the relay

// For HK4100F relay
//relay_width = 27/64.0 * 25.4;
//relay_depth = 39/64.0 * 25.4;

base_thickness = 1.12;

base_margin = 3.1;

// For large relays like Schrack
base_dim = relay_depth * 2 + relay_width + base_margin * 2;

//base_dim = 90;

base_rounding_radius = 3;

socket_lip = 1.2;
socket_margin = 0.08;
socket_height = 3.0;

socket_width = socket_margin + socket_lip*2 + relay_width;
socket_depth = socket_margin + socket_lip*2 + relay_depth;

bnc_hole_diameter = 24/64 * 25.4;
bnc_mounting_hole_radius = (bnc_hole_diameter + 0.1)/2;

bnc_mount_thickness = 2.1;
bnc_margin = 0.66;
bnc_mount_dim = 1/2 * 25.4 + bnc_margin;
bnc_mount_z_dim = bnc_mount_dim +2.5;

mounting_hole_dia = 25.4 * 9/64.0;
mounting_hole_offset = base_thickness + 3.22;

module relay_socket(){    
    translate([socket_width * -0.5, socket_depth * -0.5, 0]){
        color("red") difference(){
            cube([socket_width, socket_depth, socket_height]);
            translate([socket_lip,socket_lip,-1]){
                cube([relay_width + socket_margin, relay_depth + socket_margin, socket_height + 2]);
            }
        }
    }
}

module relay_socket_and_bnc(){
    union(){
        relay_socket();
        translate([(bnc_mount_dim + bnc_mount_thickness + socket_lip)*-1,0,0]){
            bnc_mount();
        }
    }
}

module bnc_mount(){
    translate([bnc_mount_dim*-0.5,bnc_mount_dim * -0.5,0]){
    union(){
    difference(){
        cube([bnc_mount_dim, bnc_mount_thickness, bnc_mount_z_dim]);                
        translate([bnc_mount_dim/2,2,bnc_mount_z_dim - bnc_mounting_hole_radius - (bnc_margin*2.88)]){
            rotate([-90,0,0]){
                cylinder( h = bnc_mount_thickness * 3, r = bnc_mounting_hole_radius, center = true);
            }
        }
    }
    
    translate([bnc_mount_dim,0,0]){
        difference(){
        cube([bnc_mount_thickness, bnc_mount_dim, bnc_mount_z_dim]);
        translate([1,bnc_mount_dim ,bnc_mount_dim ]){
            rotate([0,90,0]){
                scale([1.95,1.33,1]){
                    cylinder(h = bnc_mount_thickness * 2, r = (bnc_mount_dim * 0.88)/2, center = true);
                }
            }
        }
    }
    }
    
    translate([- 1 * bnc_mount_thickness,0,0]){
        difference(){
        cube([bnc_mount_thickness, bnc_mount_dim, bnc_mount_z_dim]);
        translate([1,bnc_mount_dim ,bnc_mount_dim ]){
            rotate([0,90,0]){
                scale([1.95,1.33,1]){
                    cylinder(h = bnc_mount_thickness * 2, r = (bnc_mount_dim * 0.88)/2, center = true);
                }
            }
        }
    }
    }
    
    
    }
}
}


union(){
    difference(){
        rounded_rectangle(base_dim, base_dim, base_thickness, base_rounding_radius);
        union(){
            translate([mounting_hole_offset,mounting_hole_offset,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([base_dim - mounting_hole_offset,mounting_hole_offset,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([base_dim - mounting_hole_offset,base_dim - mounting_hole_offset,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([mounting_hole_offset,base_dim - mounting_hole_offset,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([base_dim/2,base_dim/2,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
        }
    }
    
    
    translate([0,0,base_thickness]){
        translate([base_dim/2,socket_depth/2,0]){
            relay_socket_and_bnc();
        }
        
        translate([base_dim,0,0]){
            translate([socket_depth * -0.5,base_dim/2,0]){
                rotate([0,0,90]){
                    relay_socket_and_bnc();
                }
            }
        }
        
        
        translate([base_dim/2,base_dim - socket_depth/2,0]){
            rotate([0,0,180]){
                relay_socket_and_bnc();
            }
        }
        
        translate([socket_depth/2,base_dim/2,0]){
            rotate([0,0,270]){
                relay_socket_and_bnc();
            }
        }
        
        translate([bnc_mount_dim/2,socket_depth - bnc_mount_dim/2 - bnc_mount_thickness,0]){
            rotate([0,0,-90]){
                bnc_mount();
            }
        }
        
        
            
        
    }
    
    
}
